@@ -2,7 +2,7 @@
 
 cart-review checkout
 
-$Id: checkout.py 2823 2009-07-28 22:34:48Z larubbio $
+$Id: checkout.py 3302 2010-01-21 21:34:49Z larubbio $
 """
 
 
@@ -30,7 +30,7 @@ from getpaid.core.order import Order
 
 import Acquisition
 from AccessControl import getSecurityManager
-from ZTUtils import make_query as mq
+from ZTUtils import make_query
 from ZTUtils.Zope import complex_marshal
 
 from Products.Five.formlib import formbase
@@ -337,7 +337,7 @@ class CheckoutWizard( Wizard ):
             url = self.request.getURL()
             if not 'https://' in url:
                 url = url.replace("http://", "https://")
-                self.request.response.redirect('%s?%s' % (url, mq(self.request.form)))
+                self.request.response.redirect('%s?%s' % (url, make_query(self.request.form)))
         return True
 
     def __call__( self ):
@@ -741,6 +741,10 @@ class CheckoutSelectShipping( BaseCheckoutForm ):
         and returns a list of them for the template to display and the user to choose among.
 
         """
+        ship_method_code = self.request.form.get('form.shipping_method_code')
+        if type(ship_method_code) == type([]):
+            self.request.form['form.shipping_method_code'] = self.request.form['form.shipping_method_code'][-1]
+
         siteroot = getToolByName(self.context, "portal_url").getPortalObject()
         ship_service_names = IGetPaidManagementOptions(siteroot).shipping_services
 
